# Библиотека с наборами действий для использования в остальных инструментах

apps - Инкапсуляция технических действий в операции над доменами

service - Инкапсуляция действий над платформами

core - Инструменты, чтобы собрать приложение в единый инструмент

# Roadmap

[] Модуль для управления Notion
[] Модуль для управления Avito
[] Модуль для управления VK сообществом
[] Получение информации о товарах из Notion
